==> flutter_ioshttp-0.0.25.tar.gz: ios/Classes/FlutterIoshttpPlugin.m <==
#import "FlutterIoshttpPlugin.h"

@implementation FlutterIoshttpPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"flutter_ioshttp"
            binaryMessenger:[registrar messenger]];
  FlutterIoshttpPlugin* instance = [[FlutterIoshttpPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
    NSLog(call.method);
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"httpGet" isEqualToString:call.method]) {
//      NSLog(call.arguments);
      NSString *urlString = @"https://jsonplaceholder.typicode.com/todos"; //call.arguments[@"url"] ?: @"";

     NSURLSessionConfiguration *defaultSessionConfiguration = [NSURLSessionConfiguration defaultSessionConfiguration];
     NSURLSession *defaultSession = [NSURLSession sessionWithConfiguration:defaultSessionConfiguration];

      NSURL *url = [NSURL URLWithString:urlString];
      
      NSMutableURLRequest *urlRequest = [NSMutableURLRequest requestWithURL:url];
      
      [urlRequest setHTTPMethod:@"GET"];
      
      __block BOOL done = NO;
      
      NSURLSessionDataTask *dataTask = [defaultSession dataTaskWithRequest:urlRequest completionHandler:^(NSData * _Nullable data, NSURLResponse * _Nullable response, NSError * _Nullable error) {
          NSMutableDictionary *returnData = [[NSMutableDictionary alloc] initWithCapacity:3];
          NSError *e = nil;
          NSArray *json = [NSJSONSerialization JSONObjectWithData: data options:NSJSONReadingMutableContainers error:&e];
          [returnData setValue:response.description forKey:@"response"];
          [returnData setValue:json forKey:@"data"];
          [returnData setValue:error.description forKey:@"error"];
          result(returnData);
          done = YES;
      }];
      [dataTask resume];
  } else {
    result(FlutterMethodNotImplemented);
  }
}

@end

==> flutter_ioshttp-0.0.251.tar.gz: ios/Classes/FlutterIoshttpPlugin.m <==
#import "FlutterIoshttpPlugin.h"

@implementation FlutterIoshttpPlugin
+ (void)registerWithRegistrar:(NSObject<FlutterPluginRegistrar>*)registrar {
  FlutterMethodChannel* channel = [FlutterMethodChannel
      methodChannelWithName:@"flutter_ioshttp"
            binaryMessenger:[registrar messenger]];
  FlutterIoshttpPlugin* instance = [[FlutterIoshttpPlugin alloc] init];
  [registrar addMethodCallDelegate:instance channel:channel];
}

- (void)handleMethodCall:(FlutterMethodCall*)call result:(FlutterResult)result {
  if ([@"getPlatformVersion" isEqualToString:call.method]) {
    result([@"iOS " stringByAppendingString:[[UIDevice currentDevice] systemVersion]]);
  } else if ([@"httpGet" isEqualToString:call.method]) {
      NSString *urlString = call.arguments[@"url"] ?: @"";

     NSURLSessionConfiguration *defaultSessionConfiguration = [NSURLSessionConfiguration defaultSessionConfiguration];
     NSURLSession *defaultSession = [NSURLSession sessionWithConfiguration:defaultSessionConfiguration];

      NSURL *url = [NSURL URLWithString:urlString];
      
      NSMutableURLRequest *urlRequest = [NSMutableURLRequest requestWithURL:url];
      
      [urlRequest setHTTPMethod:@"GET"];
      
      __block BOOL done = NO;
      
      NSURLSessionDataTask *dataTask = [defaultSession dataTaskWithRequest:urlRequest completionHandler:^(NSData * _Nullable data, NSURLResponse * _Nullable response, NSError * _Nullable error) {
          NSMutableDictionary *returnData = [[NSMutableDictionary alloc] initWithCapacity:3];
          NSError *e = nil;
          NSArray *json = [NSJSONSerialization JSONObjectWithData: data options:NSJSONReadingMutableContainers error:&e];
          [returnData setValue:response.description forKey:@"response"];
          [returnData setValue:json forKey:@"data"];
          [returnData setValue:error.description forKey:@"error"];
          result(returnData);
          done = YES;
      }];
      [dataTask resume];
  } else {
    result(FlutterMethodNotImplemented);
  }
}

@end
